Helper datatypes for cumulus. This includes the ParentAsUmp routing type which will route
messages into an UpwardMessageSender if the destination is Parent.
Structs
- Parent
AsUmp - Xcm router which recognises the
Parentdestination and handles it by sending the message into the given UMPUpwardMessageSenderimplementation. Thus this essentially adapts anUpwardMessageSendertrait impl into aSendXcmtrait impl. - Swap
First Asset Trader - Provides an implementation of
WeightTraderto charge for weight using the first asset specified in thepaymentargument. - Take
First Asset Trader - Charges for execution in the first asset of those selected for fee payment Only succeeds for Concrete Fungible Assets First tries to convert the this Asset into a local assetId Then charges for this assetId as described by FeeCharger Weight, paid balance, local asset Id and the location is stored for later refund purposes Important: Errors if the Trader is being called twice by 2 BuyExecution instructions Alternatively we could just return payment in the aforementioned case
Traits
- Charge
Weight InFungibles - ChargeWeightInFungibles trait, which converts a given amount of weight and an assetId, and it returns the balance amount that should be charged in such assetId for that amount of weight